searchData={"items":[{"type":"module","title":"EctoPhone","doc":"A custom Ecto type for phone numbers, with configuration for default country\nprefix and formatting style.","ref":"EctoPhone.html"},{"type":"module","title":"Usage - EctoPhone","doc":"The `EctoPhone` type may be used in place of `:string` fields.\n\n``` elixir\ndefmodule MySchema do\n  use Ecto.Schema\n\n  schema \"table_name\" do\n    field :phone, EctoPhone\n    field :phone, EctoPhone, default_prefix: 1\n    field :phone, EctoPhone, format: :national\n  end\nend\n```","ref":"EctoPhone.html#module-usage"},{"type":"module","title":"Configuration - EctoPhone","doc":"``` elixir\nconfig :ecto_phone, default_prefix: 1, default_format: :national\n```\n\n`EctoPhone` may be configured at the application level with the following\noptions.\n\n- `:default_prefix`: A country prefix to use when none is provided by users.\n  Set to `1` if not configured by the application or by the field.\n- `:default_format`: The `ex_phone_number` format to use when printing\n  phone numbers as strings. Defaults to `:international`. Valid options:\n  `:e164`, `:international`, `:national`, `:rfc3966`","ref":"EctoPhone.html#module-configuration"},{"type":"type","title":"EctoPhone.format/0","doc":"","ref":"EctoPhone.html#t:format/0"},{"type":"type","title":"EctoPhone.format_modifier/0","doc":"- `e` — `:e164`\n- `i` — `:international`\n- `n` — `:national`\n- `rfc` — `:rfc3966`","ref":"EctoPhone.html#t:format_modifier/0"},{"type":"function","title":"EctoPhone.init/1","doc":"Configures a specific field with `t:init_opts/0`.\n\n``` elixir\nschema \"table_name\" do\n  field :phone, EctoPhone\n  field :phone, EctoPhone, default_prefix: 1\n  field :phone, EctoPhone, format: :national\nend\n```","ref":"EctoPhone.html#init/1"},{"type":"type","title":"EctoPhone.init_opts/0","doc":"","ref":"EctoPhone.html#t:init_opts/0"},{"type":"function","title":"EctoPhone.sigil_PHONE/2","doc":"Handles the sigil `~PHONE` for an `EctoPhone` struct.","ref":"EctoPhone.html#sigil_PHONE/2"},{"type":"function","title":"Modifers - EctoPhone.sigil_PHONE/2","doc":"- `e` — format as `:e164`\n- `i` — format as `:international`\n- `n` — format as `:national`\n- `rfc` — format as `:rfc3966`","ref":"EctoPhone.html#sigil_PHONE/2-modifers"},{"type":"type","title":"EctoPhone.t/0","doc":"","ref":"EctoPhone.html#t:t/0"},{"type":"exception","title":"EctoPhone.Error","doc":"An error providing information when a phone number may not be parsed.\n\n``` elixir\niex> Exception.message(EctoPhone.Error.exception(type: :format))\n\"expected to be in the format +1 ###-###-####\"\n\niex> Exception.message(EctoPhone.Error.exception(type: :validation))\n\"is not a valid phone number\"\n\niex> Exception.message(EctoPhone.Error.exception(type: :unknown))\n\"is not valid\"\n\niex> Exception.message(EctoPhone.Error.exception(message: \"is the wrong shape\"))\n\"is the wrong shape\"\n```","ref":"EctoPhone.Error.html"},{"type":"type","title":"EctoPhone.Error.t/0","doc":"","ref":"EctoPhone.Error.html#t:t/0"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 [synchronal.dev](https://github.com/synchronal)\n\nPermission is hereby granted, free of charge, to any person obtaining a\ncopy of this software and associated documentation files (the\n\"Software\"), to deal in the Software without restriction, including\nwithout limitation the rights to use, copy, modify, merge, publish,\ndistribute, sublicense, and/or sell copies of the Software, and to\npermit persons to whom the Software is furnished to do so, subject to\nthe following conditions:\n\nThe above copyright notice and this permission notice shall be included\nin all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS\nOR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF\nMERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.\nIN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY\nCLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,\nTORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE\nSOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"},{"type":"extras","title":"Change log","doc":"# Change log","ref":"changelog.html"},{"type":"extras","title":"2.0.2 - Change log","doc":"- Fix parsing Swedish landline number without prefix. Thanks\n   !","ref":"changelog.html#2-0-2"},{"type":"extras","title":"2.0.1 - Change log","doc":"- Only add default prefix when the phone number does not already begin\n  with it.","ref":"changelog.html#2-0-1"},{"type":"extras","title":"2.0.0 - Change log","doc":"- Test against Elixir 1.18.\n- **Breaking change:** drop support for Elixir 1.15.","ref":"changelog.html#2-0-0"},{"type":"extras","title":"1.1.0 - Change log","doc":"- Implement `Phoenix.HTML.Safe` when `phoenix_html` is present.","ref":"changelog.html#1-1-0"},{"type":"extras","title":"1.0.2 - Change log","doc":"- `inspect` returns a phone sigil.","ref":"changelog.html#1-0-2"},{"type":"extras","title":"1.0.1 - Change log","doc":"- Docs open to main module.\n- Fix error specs.","ref":"changelog.html#1-0-1"},{"type":"extras","title":"1.0.0 - Change log","doc":"- Initial release","ref":"changelog.html#1-0-0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}